UntypedActor class
This class is a base class for actors who don't have initial special role (like GroupRouterActor or PoolRouterActor - they initial role are routing messages).
Most of the time you will use this actor for creating your actors.
- Inheritance
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createMailboxFactory(
) → MailboxFactory< Mailbox> -
Creates MailboxFactory which will be used to create Mailbox for actor.
inherited
-
createSupervisorStrategy(
) → SupervisorStrategy -
Creates SupervisorStrategy which the actor will use.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onKill(
UntypedActorContext context) → FutureOr< void> -
This method is called before actor will killed (before him Isolate will killed).
inherited
-
onPause(
UntypedActorContext context) → FutureOr< void> -
This method is called before actor will paused (before him Isolate will paused).
inherited
-
onResume(
UntypedActorContext context) → FutureOr< void> -
This method is called after actor resumed (after him Isolate resumed).
inherited
-
onStart(
UntypedActorContext context) → FutureOr< void> -
This method is called after actor started (after him Isolate started).
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited